package Bio::Medpost::Var;

our $medpost_path = '.....';

use File::Spec::Functions;
our $medpost_script = catfile($medpost_path, 'medpost');

1;
